<TS version="2.1" language="tl">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">pindutin lamang ang kanang pindutan upang i-edit ang address o label.</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Lumikha ng bagong ♦address♦</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">Panibago</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">Gayahin</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">(Do you mean: Close?) :isara, sarado </translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Burahin ang kasalukuyang napiling ♦address♦ sa listahan</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Ilagay ang address o tatak na hahanapin</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">I-export ang datos sa kasalukuyang ♦tab♦ sa isang file</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;I-export</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Burahin</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Piliin ang ♦address♦ kung saan ipapadala ang mga barya</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Piliin ang ♦address♦ kung saan tatanggap ng mga coin</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">(do you mean: CHOOSE?) ;Pumili,Piliin.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Ito ang mga ♦address♦ ng ♦Bitcoin♦ mo para pagpapadala ng mga bayad. Palaging suriin mo ang halaga at address kung saan tatanggap bago magpadala ka ng mga ♦coin.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">Ito ang mga address ng ♦Bitcoin♦ para sa pagtanggap ng mga baya. Gamitin ang 'Create new receiving address' na button sa receive tab para gumawa ng bagong mga address. Ang pag-sign ay posible lamang sa uri ng mga address na 'legacy'.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Kopyahin ang ♦Address♦</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Kopyahin ang &amp;Tatak</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;I-edit</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">I-Export ang Listahan ng ♦Address♦</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Kuwir hiwalay na file</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">May mali sa pagsubok na i-save ang listahan ng address  sa %1. Pakisubukan ulit.</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Ang pag-export ay Nabigo</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Tatak</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">♦Address♦</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(walang tatak)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">♦Passphrase♦ na ♦Dialog♦</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Ilagay ang ♦passphrase♦</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Bagong ♦passphrase♦</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Ulitin ang bagong ♦passphrase♦</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Ipakita ang ♦passphrase♦</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">I-encrypt ang pitaka</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Ang operasyon na ito ay nangangailangan ng iyong pitaka ♦passphrase♦ para i-unlock ang pitaka.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">I-unlock ang pitaka</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Palitan ang ♦passphrase♦</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Kumpirmahin ang ♦encryption♦ ng pitaka</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Babala: IKung i-encrypt mo ang iyong pitaka at mawawala ang ♦passphrase♦,  &lt;b&gt;MAWAWALA MO ANG LAHAT NG IYONG MGA BITCOIN&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Sigurado ka ba na gusto mong i-encrypt ang iyong pitaka?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Ang pitaka ay na-encrypt na</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">Ilagay ang bagong ♦passphrase♦ para sa pitaka.&lt;br/&gt;Pakigamit ang ♦passphrase♦ of &lt;b&gt;sampu o higit pa na mga ♦random♦ na mga karakter&lt;/b&gt;, o &lt;b&gt;walo o higit pang mga salita&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">Ilagay ang lumang ♦passphrase♦ at ang bagong ♦passphrase♦ para sa pitaka.</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">Tandaan na ang pag-encrypt sa iyong pitaka ay hindi ganap na mapoprotektahan ang mga ♦bitcoin♦ sa pagnanakaw ng ♦malware♦ na makakahawa sa iyong kompyuter.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Ang pitaka ay i-encrypt</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">Ang iyong pitaka ay mae-encrypt na.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">Ang iyong pitaka ay na-encrypt na.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">MAHALAGA: Kahit anong dating mga ♦backup♦ na ginawa mo sa ♦file♦ ng pitaka mo ay dapat na mapalitan ng bagong gawang, na-encrypt na ♦file♦ ng pitaka. Para sa mga rason ng seguridad, dating mga ♦backup♦ sa hindi na-encrypt na ♦file♦ ng pitaka ay magiging walang silbi sa lalong madaling panahon na sisimulan mong gamitin ang bago, na na-encrypt na pitaka.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Ang pag-encrypt sa pitaka ay nabigo</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Nabigo ang pag-encrypt sa pitaka dahil sa panloob na pagkakamali. Ang iyong pitaka ay hindi na-encrypt.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Ang mga ibinigay na mga ♦passphrase♦ ay hindi nagtugma.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Ang pag-unlock sa pitaka ay nabigo</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Ang ♦passphrase♦ na ipinasok sa ♦decryption♦ sa pitaka ay hindi tama.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Ang ♦passphrase♦ ng pitaka ay matagumpay na nabago.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Babala: Ang ♦Caps Lock Key♦ ay naka-on!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation type="unfinished">♦IP/Netmask♦</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Ipinagbabawal Hanggang</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Runaway exception</source>
        <translation type="unfinished">Pagbubukod sa pagtakbo papalayo </translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">Malubhang pagkakamali ay naganap. %1 hindi na pwedeng magpatuloy ng ligtas at ihihinto na.</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Panloob na pagkakamali</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">May panloob na pagkakamali ang naganap. %1 ay magtatangkang ituloy na ligtas. Ito ay hindi inaasahan na problema na maaaring i-ulat katulad ng pagkalarawan sa ibaba.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">Gusto mo bang i-reset ang mga ♦setting♦ sa ♦default♦ na mga ♦value♦, o itigil na hindi gumagawa ng mga pagbabago?</translation>
    </message>
    <message>
        <source>A fatal error occurred. Check that settings file is writable, or try running with -nosettings.</source>
        <extracomment>Explanatory text shown on startup when the settings file could not be written. Prompts user to check that we have the ability to write to the file. Explains that the user has the option of running without a settings file.</extracomment>
        <translation type="unfinished">Isang malubhang pagkakamali ang naganap. Suriin ang mga ♦setting♦ ng ♦file♦ na ♦writable♦, o subukan na patakbuhin sa ♦-nosettings♦.</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Pagkakamali: %1</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1 hindi pa nag-exit ng ligtas...</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Halaga</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">pitaka na ♦default♦</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;Pangkalahatang ideya</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">Ipakita ang pangkalahatang ideya ng pitaka</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Mga transaksyon</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Tignan ang kasaysayan ng transaksyon</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">♦E&amp;xit</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Ihinto ang aplikasyon</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;Tungkol sa %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">Ipakita ang impormasyon tungkol sa %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Patungkol sa &amp;♦Qt♦</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Ipakita ang impormasyon tungkol sa Qt</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">Baguhin ang mga pagpipilian sa ♦configuration♦ para sa %1</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Gumawa ng bagong pitaka</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">Bawasan</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Pitaka:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">Na-disable ang aktibidad ng ♦network♦</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Magpadala ng mga ♦coin♦ sa ♦address♦ ng Bitcoin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">I-backup ang pitaka sa ibang lokasyon</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Palitan ang ♦passphrase♦ na ginamit para sa pag-encrypt sa pitaka</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Ipadala</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Tumanggap</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;Mga pagpipilian...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">&amp;I-encrypt ang Pitaka</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">I-encrypt ang mga pribadong mga susi na nabibilang sa iyong pitaka</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet…</source>
        <translation type="unfinished">&amp;I-backup ang Pitaka...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">&amp;Palitan ang ♦Passphrase♦...</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">Pirmahan &amp;magmensahe...</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Tanda na mga mensahe sa mga ♦address♦ ng iyong ♦Bitcoin♦ para patunayan na pagmamay-ari mo sila</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp;Patunayan ang mensahe...</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">Patunayan ang mga mensahe para matiyak na sila ay napirmahan ng may tinukoy na mga ♦Bitcoin address♦</translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file…</source>
        <translation type="unfinished">&amp;I-load ang PSBT mula sa ♦file♦...</translation>
    </message>
    <message>
        <source>Open &amp;URI…</source>
        <translation type="unfinished">Buksan ang &amp;♦URL♦...</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">Isara ang Pitaka...</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">Gumawa ng Pitaka...</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">Isara ang Lahat ng mga Pitaka...</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;♦File♦</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">Mga &amp;♦Setting♦</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Tulungan</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">♦Tabs toolbar♦</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)…</source>
        <translation type="unfinished">♦Syncing Headers♦ (%1%)…</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">Sini-siynchronize sa ♦network♦...</translation>
    </message>
    <message>
        <source>Indexing blocks on disk…</source>
        <translation type="unfinished">Ini-index ang mga bloke sa ♦disk♦...</translation>
    </message>
    <message>
        <source>Processing blocks on disk…</source>
        <translation type="unfinished">Pinoproseso ang mga bloke sa ♦disk♦...</translation>
    </message>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">Kumokonekta sa mga ♦peers♦...</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">Humiling ng mga bayad (gumagawa ng ♦QR codes♦ at ♦bitcoin: URIs♦)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">Ipakita ang listahan ng nagamit na pagpapadalhan na mga ♦address♦ at mga tatak</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">Ipakita ang listahan ng nagamit na pagtatanggapan na mga ♦address♦ at mga tatak</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">&amp;♦Command-line♦ na mga pagpipilian</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 sa likod</translation>
    </message>
    <message>
        <source>Catching up…</source>
        <translation type="unfinished">Humahabol...</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">Ang huling natanggap na bloke ay nagawa %1kanina.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">Ang mga transaksyon pagkatapos nito ay hindi pa muna makikita.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Nagkamali</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Babala</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Impormasyon</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">napapapanahon</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction</source>
        <translation type="unfinished">Ang ♦Load♦ ay Bahagyang Napirmahan na Transaksyon sa ♦Bitcoin♦</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction from clipboard</source>
        <translation type="unfinished">Ang ♦Load♦ ay Bahagyang Napirmahan na Transaksyon sa ♦Bitcoin♦ mula sa ♦clipboard♦</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">♦Node window♦</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation type="unfinished">Bukas na ♦node debugging♦ at ♦diagnostic console♦</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Pagpapadalhan na mga ♦address♦</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation type="unfinished">Buksan ang ♦bitcoin: URI♦</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">Buksan ang pitaka</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">Buksan ang pitaka</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Isarado ang pitaka</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Isarado ang lahat na mga pitaka</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation type="unfinished">Ipakita ang %1 tumulong sa mensahe na kumuha ng listahan ng posibleng ♦Bitcoin command-line♦ na mga pagpipilian</translation>
    </message>
    <message>
        <source>&amp;Mask values</source>
        <translation type="unfinished">&amp;♦Mask♦ na mga halaga</translation>
    </message>
    <message>
        <source>Mask the values in the Overview tab</source>
        <translation type="unfinished">I-mask ang  mga halaga sa loob ng ♦Overview tab♦</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation type="unfinished">Walang pitaka na mayroon</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">Pangalan ng pitaka</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;♦Window♦</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">I-zoom</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">Pangunahing ♦Window♦</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">%1 na kliyente</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation type="unfinished">&amp;Itago</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform>%n aktibo na mga ♦connection(s)♦ sa ♦Bitcoin network♦.</numerusform>
            <numerusform>%n na aktibong mga koneksyon sa ♦Bitcoin network♦</numerusform>
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">Mag-click para sa marami pang gagawin.</translation>
    </message>
    <message>
        <source>Show Peers tab</source>
        <extracomment>A context menu item. The "Peers tab" is an element of the "Node window".</extracomment>
        <translation type="unfinished">Ipakita ang ♦Peers tab♦</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">I-disable ang aktibidad ng ♦network♦</translation>
    </message>
    <message>
        <source>Enable network activity</source>
        <extracomment>A context menu item. The network activity was disabled previously.</extracomment>
        <translation type="unfinished">I-enable ang aktibidad ng ♦network♦</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Pagkakamali: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation type="unfinished">Babala: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">Petsa: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">Halaga: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation type="unfinished">Pitaka: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation type="unfinished">Uri: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation type="unfinished">Tatak: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">♦Address♦: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation type="unfinished">Ipinadalang transaksyon</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation type="unfinished">Paparating na transaksyon</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation type="unfinished">♦HD♦ na susi sa henerasyon ay &lt;b&gt;na-enable&lt;/b&gt;</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">♦HD key generation♦ ay &lt;b&gt;na-disable&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">Pribadong susi &lt;b&gt;na-disable&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation type="unfinished">Ang pitaka ay &lt;b&gt;na-encrypt&lt;/b&gt; at kasalukuyang &lt;b&gt;na-unlock&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation type="unfinished">Ang pitaka ay &lt;b&gt;na-encrypt&lt;/b&gt; at kasalukuyang &lt;b&gt;na-lock&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation type="unfinished">Orihinal na mensahe:</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    <message>
        <source>Unit to show amounts in. Click to select another unit.</source>
        <translation type="unfinished">Yunit na ipakita sa mga halaga. Mag-click para pumili ng ibang yunit.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation type="unfinished">Pagpipilian ng ♦coin♦</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Dami:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">♦Bytes♦:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Halaga:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Bayad:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Pagkatapos na Bayad:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Sukli:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation type="unfinished">i-(un)select lahat</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation type="unfinished">♦Tree mode♦</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation type="unfinished">Listajhan na ♦mode♦</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Halaga</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation type="unfinished">Natanggap na may kasamang ♦tatak♦</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation type="unfinished">Natanggap na may ♦address♦</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Petsa</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation type="unfinished">Mga kumpirmasyon</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Nakumpirma</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Kopyahin ang halaga</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Kopyahin ang ♦address♦</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Kopyahin ang &amp;tatak</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Kopyahin ang &amp;halaga</translation>
    </message>
    <message>
        <source>L&amp;ock unspent</source>
        <translation type="unfinished">&amp;I-lock ang hindi nagastos</translation>
    </message>
    <message>
        <source>&amp;Unlock unspent</source>
        <translation type="unfinished">&amp;I-unlock ang hindi nagastos</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Kopyahin ang dami</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Bayad sa pagkopya</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Kopyahin pagkatapos ang bayad</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Kopyahin ang ♦bytes♦</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Kopyahin ang pagbabago</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation type="unfinished">(%1 naka-lock)</translation>
    </message>
    <message>
        <source>Can vary +/- %1 satoshi(s) per input.</source>
        <translation type="unfinished">Maaaring magbago ng +/- %1♦4satoshi(s)♦ kada ♦input♦.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(walang tatak)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation type="unfinished">ang pagbabago ay mula sa %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation type="unfinished">(pagbabago)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation type="unfinished">Gumawa ng pitaka</translation>
    </message>
    <message>
        <source>Creating Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the create wallet progress window which indicates to the user which wallet is currently being created.</extracomment>
        <translation type="unfinished">Paggawa ng Pitaka &lt;b&gt;%1&lt;/b&gt;…</translation>
    </message>
    <message>
        <source>Create wallet failed</source>
        <translation type="unfinished">Ang paggawa ng pitaka ay nabigo</translation>
    </message>
    <message>
        <source>Create wallet warning</source>
        <translation type="unfinished">Babala sa paggawa ng pitaka</translation>
    </message>
    <message>
        <source>Can't list signers</source>
        <translation type="unfinished">Hindi mailista ang mga tagapirma</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>Open wallet failed</source>
        <translation type="unfinished">Pagbukas ng pitaka ay nabigo</translation>
    </message>
    <message>
        <source>Open wallet warning</source>
        <translation type="unfinished">Babala sa pagbukas ng pitaka</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation type="unfinished">Buksan ang pitaka</translation>
    </message>
    <message>
        <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the open wallet progress window which indicates to the user which wallet is currently being opened.</extracomment>
        <translation type="unfinished">Pagbukas sa Pitaka &lt;b&gt;%1&lt;/b&gt;…</translation>
    </message>
</context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Isarado ang pitaka</translation>
    </message>
    <message>
        <source>Are you sure you wish to close the wallet &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation type="unfinished">Sigurado ka ba na gusto mong isarado ang pitaka &lt;i&gt;%1&lt;/i&gt;?</translation>
    </message>
    <message>
        <source>Closing the wallet for too long can result in having to resync the entire chain if pruning is enabled.</source>
        <translation type="unfinished">Ang pagsasarod sa pitaka sa matagal ay maaaring humantong sa pag-resync ng kabuuang ♦chain♦ kung ang pagputol ay na-enable.</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Isarado ang lahat na mga pitaka</translation>
    </message>
    <message>
        <source>Are you sure you wish to close all wallets?</source>
        <translation type="unfinished">Sigurado ka ba na gusto mong isarado lahat ng mga pitaka?
</translation>
    </message>
</context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation type="unfinished">Gumawa ng pitaka</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation type="unfinished">Pangalan ng pitaka</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Pitaka</translation>
    </message>
    <message>
        <source>Encrypt the wallet. The wallet will be encrypted with a passphrase of your choice.</source>
        <translation type="unfinished">I-encrypt ang pitaka. Ang pitaka ay mae-encrypt na may ♦passphrase♦ ng iyong mapipili.</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation type="unfinished">I-encrypt ang pitaka</translation>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation type="unfinished">Mga Pagpipilian sa pagsulong</translation>
    </message>
    <message>
        <source>Disable private keys for this wallet. Wallets with private keys disabled will have no private keys and cannot have an HD seed or imported private keys. This is ideal for watch-only wallets.</source>
        <translation type="unfinished">I-disable ang mga pribadong mga susi para sa pitaka na ito. Ang mga pitaka na may mga pribadong mga susi na na-disable ay mawawalng ng pribadong mga susi at hindi magkakaroon ng ♦HD seed♦ o mga na-import na pribadong mga susi. Ito ay perpekto lamang para sa mga ♦watch-only♦ na mga pitaka.</translation>
    </message>
    <message>
        <source>Disable Private Keys</source>
        <translation type="unfinished">I-disable ang Pribadong mga Susi</translation>
    </message>
    <message>
        <source>Make a blank wallet. Blank wallets do not initially have private keys or scripts. Private keys and addresses can be imported, or an HD seed can be set, at a later time.</source>
        <translation type="unfinished">Gumawa ng blankong pitaka. Ang blankong mga pitaka hindi muna nagkakaroon ng pribadong mga susi o mga ♦script♦. Ang pribadong mga susi at mga ♦address♦ ay pwedeng ma-import, o ang ♦HD seed♦ ay pwedeng mai-set, mamaya.</translation>
    </message>
    <message>
        <source>Make Blank Wallet</source>
        <translation type="unfinished">Gumawa ng Blankong Pitaka</translation>
    </message>
    <message>
        <source>Use an external signing device such as a hardware wallet. Configure the external signer script in wallet preferences first.</source>
        <translation type="unfinished">Gumamit ng panlabas na pagpirmang ♦device♦ katulad ng ♦hardware♦ na pitaka. I-configure ang panlabas na ♦signer script♦ sa loob ng ♦preferences♦ ng pitaka n listahan. </translation>
    </message>
    <message>
        <source>External signer</source>
        <translation type="unfinished">Panlabas na ♦signer♦</translation>
    </message>
    <message>
        <source>Create</source>
        <translation type="unfinished">Gumawa</translation>
    </message>
    <message>
        <source>Compiled without external signing support (required for external signing)</source>
        <extracomment>"External signing" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">Pinagsama-sama na walang suporta ng ♦pag-pirma♦ (kailangan para sa panlabasna pagpirma)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">I-edit ang ♦address♦</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;Tatak</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation type="unfinished">Ang tatak na nauugnay sa ♦entry♦ ng listahan ng ♦address♦</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation type="unfinished">Ang ♦address♦ na may kaugnayan sa ipinasok sa listahan ng ♦address♦. Ito ay maaari lamang ng mabago para sa pagpapadalhan na mga ♦address♦.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;♦Address♦</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation type="unfinished">Bagong pagpapadalhan na ♦address♦</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation type="unfinished">I-edit ang pagtatanggapang ♦address♦</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">I-edit ang pagpapadalhan na ♦address♦</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation type="unfinished">Ang naipasok na ♦address♦ "%1" ay hindi wasto na ♦Bitcoin address♦.</translation>
    </message>
    <message>
        <source>Address "%1" already exists as a receiving address with label "%2" and so cannot be added as a sending address.</source>
        <translation type="unfinished">Ang ♦Address♦ "%1" ay mayroon na bilang pagtatanggapang ♦address♦ na may tatak "%2" kaya hindi na maaaring maidagdag bilang pagpapadalhan na ♦address♦.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book with label "%2".</source>
        <translation type="unfinished">Ang naipasok na ♦address♦ "%1" ay nasa aklat na ng ♦address♦ na may tatak "%2".</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Hindi maaaring ma-unlock ang pitaka.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation type="unfinished">Ang Bagong susi sa ♦generation♦ ay nabigo.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation type="unfinished">May bagong datos na ♦directory♦ ay magagawa.</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="unfinished">pangalan</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation type="unfinished">Ang ♦directory♦ ay mayroon na. Magdagdag ng%1kung balak mong gumawa ng bagong ♦directory♦ dito.</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation type="unfinished">Ang ♦path♦ ay mayroon na, at hindi ♦directory♦.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation type="unfinished">Hindi makakagawa ng datos na ♦directory♦ dito.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation type="unfinished">bersyon</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>Do not shut down the computer until this window disappears.</source>
        <translation type="unfinished">Huwag Patayin ang inyong kompyuter hanggang mawala ang window na ito.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">Maligayang Pagdating</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation type="unfinished">♦Bitcoin♦</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
        <translation type="unfinished">Hindi bababa sa %1 ng ♦GB♦ na dato ay mailalagay sa ♦directory♦, at lalaki sa paglipas ng panahon.</translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Nagkamali</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>&amp;Main</source>
        <translation type="unfinished">&amp;♦Main♦</translation>
    </message>
    <message>
        <source>&amp;Start %1 on system login</source>
        <translation type="unfinished">&amp;Simulan %1 sa pag-login sa sistema</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation type="unfinished">Laki ng &amp;♦database cache♦</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation type="unfinished">Bilang ng ♦script♦ &amp;pagpapatunay na mga ♦threads♦</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation type="unfinished">Mga pagpipilian sa &amp;Pag-reset</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">&amp;♦Network♦</translation>
    </message>
    <message>
        <source>Prune &amp;block storage to</source>
        <translation type="unfinished">Putulan &amp;i-block ang imbakan sa</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">&amp;Pitaka</translation>
    </message>
    <message>
        <source>Enable coin &amp;control features</source>
        <translation type="unfinished">I-enable ang pag-control na mga tampok ng ♦coin♦ </translation>
    </message>
    <message>
        <source>&amp;Spend unconfirmed change</source>
        <translation type="unfinished">&amp;Gumastos ng hindi nakumpirmang pagbabago</translation>
    </message>
    <message>
        <source>&amp;External signer script path</source>
        <translation type="unfinished">&amp;Panlabas na ♦signer script♦ na daanan</translation>
    </message>
    <message>
        <source>Allow incomin&amp;g connections</source>
        <translation type="unfinished">Pahintulutan ang paparating na mga &amp;koneksyon</translation>
    </message>
    <message>
        <source>&amp;Connect through SOCKS5 proxy (default proxy):</source>
        <translation type="unfinished">&amp;Kumonketa sa pamamagitan ng ♦SOCKS5 proxy (default proxy)♦:</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;♦Window♦</translation>
    </message>
    <message>
        <source>Compiled without external signing support (required for external signing)</source>
        <extracomment>"External signing" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">Pinagsama-sama na walang suporta ng ♦pag-pirma♦ (kailangan para sa panlabasna pagpirma)</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Nagkamali</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">♦Address♦</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Node window</source>
        <translation type="unfinished">♦Node window♦</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer.</extracomment>
        <translation type="unfinished">&amp;Kopyahin ang ♦address♦</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Kopyahin ang ♦address♦</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Kopyahin ang &amp;tatak</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Kopyahin ang &amp;halaga</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Hindi maaaring ma-unlock ang pitaka.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Halaga:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Pitaka:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Petsa</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Tatak</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(walang tatak)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Dami:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">♦Bytes♦:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Halaga:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Bayad:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Pagkatapos na Bayad:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Sukli:</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Kopyahin ang dami</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Kopyahin ang halaga</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Bayad sa pagkopya</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Kopyahin pagkatapos ang bayad</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Kopyahin ang ♦bytes♦</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Kopyahin ang pagbabago</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(walang tatak)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Petsa</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Halaga</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Petsa</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Tatak</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(walang tatak)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Kopyahin ang ♦address♦</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Kopyahin ang &amp;tatak</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Kopyahin ang &amp;halaga</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">Kopyahin ang transaksyon  ng &amp;♦ID♦</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Kuwir hiwalay na file</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Nakumpirma</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Petsa</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Tatak</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">♦Address♦</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Ang pag-export ay Nabigo</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Gumawa ng bagong pitaka</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Nagkamali</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;I-export</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">I-export ang datos sa kasalukuyang ♦tab♦ sa isang file</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">pitaka na ♦default♦</translation>
    </message>
    <message>
        <source>Settings file could not be read</source>
        <translation type="unfinished">Ang mga ♦setting file♦ ay hindi mabasa</translation>
    </message>
    <message>
        <source>Settings file could not be written</source>
        <translation type="unfinished">Ang mga ♦settings file♦ ay hindi maisulat</translation>
    </message>
</context>
</TS>